#install.packages('simmr')

library(simmr)
library(readr)
targets <- read_delim("U:/temp/phD/Data/Macroalgae_tissue/Target_SI_Disko_outofrange_20220308.csv", 
                      ";", escape_double = FALSE, locale = locale(decimal_mark = ",", 
                                                                  grouping_mark = "."), trim_ws = TRUE)
#All sources- other than Greenland included
sources <- read_delim("U:/temp/phD/Data/Macroalgae_tissue/Sources_stable_isotopes.csv", 
                      ";", escape_double = FALSE, locale = locale(decimal_mark = ",", 
                                                                  grouping_mark = "."), trim_ws = TRUE)
#grouped sources - other than Greenland included
sources <- read_delim("U:/temp/phD/Data/Macroalgae_tissue/Sources_grouped_stable_isotopes.csv", 
                      ";", escape_double = FALSE, locale = locale(decimal_mark = ",", 
                                                                  grouping_mark = "."), trim_ws = TRUE)
#grouped averages sources - only data from Greenland
sources <- read_delim("U:/temp/phD/Data/Macroalgae_tissue/Sources_grouped_average_SI_greenland.csv", 
                      ";", escape_double = FALSE, locale = locale(decimal_mark = ",", 
                                                                  grouping_mark = "."), trim_ws = TRUE)

#grouped averages sources - only data from Greenland - Macroalgae and P-POM
sources <- read_delim("U:/temp/phD/Data/Macroalgae_tissue/Sources_grouped_average_SI_greenland_Algae_POM_updated_Feb22.csv", 
                      ";", escape_double = FALSE, locale = locale(decimal_mark = ",", 
                                                                  grouping_mark = "."), trim_ws = TRUE)

#grouped averages sources - only data from Greenland - Algae, POM, eelgrass, terri
sources <- read_delim("U:/temp/phD/Data/Macroalgae_tissue/Sources_grouped_average_SI_greenland_Algae_POM_Eelgrass_terri_updated_Feb22.csv", 
                      ";", escape_double = FALSE, locale = locale(decimal_mark = ",", 
                                                                  grouping_mark = "."), trim_ws = TRUE)
#load the data into simmr
sed_simmr <- simmr_load(mixtures = as.matrix(targets[, 1:2]),
                         source_names = sources$Sources,
                         source_means = as.matrix(sources[,2:3]),
                         source_sds = as.matrix(sources[,4:5]),
                         group = as.factor(targets$ID))

#Plot the data 
plot(sed_simmr, group = 1:2, xlab = expression(paste(delta^13, "C (\u2030)", 
                                                     sep = "")), 
     ylab = expression(paste(delta^15, "N (\u2030)",
                             sep = "")))

#run through simmr and check convergence - should be close to 1, if above 1.1 run shoulf be longer - check website
sed_simmr_out <- simmr_mcmc(sed_simmr)
summary(sed_simmr_out, type = 'diagnostics')

#Check the model fit
post_pred <- posterior_predictive(sed_simmr_out)
print(post_pred)

summary(sed_simmr_out,type='statistics')

#Look at the output and influence of the prior
prior_viz(sed_simmr_out, group = 3)
summary(sed_simmr_out, type = 'statistics')
summary(sed_simmr_out, type = 'quantiles')

#Histogram and matrix of proportions
plot(sed_simmr_out, type = c('density','histogram','matrix'),
                             group = 2,
                             title = 'simmr output Nuuk')

#Boxplot of proportions between gropus
compare_groups(sed_simmr_out, groups = 1:18,
               source_name = 'Macroalgae')

compare_groups(sed_simmr_out, groups = 21:29, 
               source_name = 'Macroalgae')

compare_groups(sed_simmr_out, groups = 1:9, 
               source_name = 'P-POM-Autumn + Spring')

compare_groups(sed_simmr_out, groups = 1:24, 
               source_name = 'Brown + red algae')

compare_groups(sed_simmr_out, groups = 1:24, 
               source_name = 'Green algae')

mean(sed_simmr_out$output[[1]][,1])
str(sed_simmr_out)

# First extract the dietary proportions
sed_simmr_out2 = sed_simmr_out$output[[1]]$BUGSoutput$sims.list$p
colnames(sed_simmr_out2) = sed_simmr_out$input$source_names



#comparison of source proportions
compare_sources(sed_simmr_out, group = 1)
compare_sources(sed_simmr_out, group = 2)
compare_sources(sed_simmr_out, group = 3)
compare_sources(sed_simmr_out, group = 4)
compare_sources(sed_simmr_out, group = 5)
compare_sources(sed_simmr_out, group = 6)
compare_sources(sed_simmr_out, group = 7)
compare_sources(sed_simmr_out, group = 8)
compare_sources(sed_simmr_out, group = 9)
compare_sources(sed_simmr_out, group = 10)
compare_sources(sed_simmr_out, group = 11)
compare_sources(sed_simmr_out, group = 12)
compare_sources(sed_simmr_out, group = 13)
compare_sources(sed_simmr_out, group = 14)
compare_sources(sed_simmr_out, group = 15)
compare_sources(sed_simmr_out, group = 16)
compare_sources(sed_simmr_out, group = 17)
compare_sources(sed_simmr_out, group = 18)
compare_sources(sed_simmr_out, group = 19)
compare_sources(sed_simmr_out, group = 20)
compare_sources(sed_simmr_out, group = 21)
compare_sources(sed_simmr_out, group = 22)
compare_sources(sed_simmr_out, group = 23)
compare_sources(sed_simmr_out, group = 24)
compare_sources(sed_simmr_out, group = 25)
compare_sources(sed_simmr_out, group = 26)
compare_sources(sed_simmr_out, group = 27)
compare_sources(sed_simmr_out, group = 28)
compare_sources(sed_simmr_out, group = 29)

help(compare_sources)

# using the Mixing Polygon Simulation
#See U:/temp/Manuskripter/Arctic_surface_sediments/Scripts/MixPolySim_2iso